@@ -213,7 +213,7 @@ SCM_DEFINE (scm_gtype_fundamental_p, "gtype-fundamental?", 1, 0, 0,
 
 SCM_DEFINE (scm_gtype_to_fundamental, "gtype->fundamental", 1, 0, 0,
 	    (SCM type),
-	    "Returns the fundamental type of @var{type} (possible @var{type} itself).")
+	    "Returns the fundamental type of @var{type} (possibly @var{type} itself).")
 #define FUNC_NAME s_scm_gtype_to_fundamental
 {
     GType gtype, fundamental;
@@ -228,7 +228,7 @@ SCM_DEFINE (scm_gtype_to_fundamental, "gtype->fundamental", 1, 0, 0,
 
 SCM_DEFINE (scm_gtype_parent, "gtype-parent", 1, 0, 0,
 	    (SCM type),
-	    "Returns the parent type of @var{type} (possible @var{type} itself).")
+	    "Returns the parent type of @var{type} (possibly @var{type} itself).")
 #define FUNC_NAME s_scm_gtype_parent
 {
     GType gtype;
@@ -263,7 +263,7 @@ SCM_DEFINE (scm_gtype_children, "gtype-children", 1, 0, 0,
 
 SCM_DEFINE (scm_gtype_interfaces, "gtype-interfaces", 1, 0, 0,
 	    (SCM type),
-	    "")
+	    "Returns the set of @code{<gtype>}'s that @var{type} implements, as a list.")
 #define FUNC_NAME s_scm_gtype_interfaces
 {
     GType gtype, *interfaces;
@@ -312,7 +312,7 @@ SCM_DEFINE (scm_gtype_from_name, "gtype-from-name", 1, 0, 0,
 
 SCM_DEFINE (scm_gtype_from_instance, "gtype-from-instance", 1, 0, 0,
 	    (SCM instance),
-	    "Returns the type of @var{instance}.")
+	    "Returns the type of @var{instance}, which should be a primitive @code{<%gtype-instance>}.")
 #define FUNC_NAME s_scm_gtype_from_instance
 {
     GTypeInstance *ginstance;
@@ -371,7 +371,7 @@ scm_gtype_class_print (SCM smob, SCM port, scm_print_state *pstate)
 
 SCM_DEFINE (scm_sys_gtype_lookup_class, "%gtype-lookup-class", 1, 0, 0,
 	    (SCM type),
-	    "")
+	    "Returns the @code{<gtype-class>} registered for @var{type}, or @code{#f} if none has been registered.")
 #define FUNC_NAME s_scm_sys_gtype_lookup_class
 {
     GType gtype;
@@ -415,7 +415,9 @@ scm_c_gtype_to_class (GType gtype)
 
 SCM_DEFINE (scm_sys_gtype_bind_to_class, "%gtype-bind-to-class", 2, 0, 0,
 	    (SCM class, SCM type),
-	    "")
+	    "A low-level procedure to bind the newly-created "
+            "@code{<gtype-class>} @var{class} to @var{type}. Users should "
+            "not need to call this function.")
 #define FUNC_NAME s_scm_sys_gtype_bind_to_class
 {
     SCM type_class;
@@ -574,7 +576,12 @@ scm_gtype_instance_print (SCM smob, SCM port, scm_print_state *pstate)
 
 SCM_DEFINE (scm_sys_gtype_instance_primitive_destroy_x, "%gtype-instance-primitive-destroy!", 1, 0, 0,
 	    (SCM instance),
-	    "")
+	    "Release all references that the Scheme wrapper @var{instance} "
+            "has on the underlying C value, and release pointers associated "
+            "with the C value that point back to Scheme.\n\n"
+            "Normally not necessary. Used by the implementations of some "
+            "instantiatable types that have @code{destroy} methods, "
+            "notably @code{<gtk-object>}.")
 #define FUNC_NAME s_scm_sys_gtype_instance_primitive_destroy_x
 {
     SCM_VALIDATE_GTYPE_INSTANCE (1, instance);
@@ -587,7 +594,8 @@ SCM_DEFINE (scm_sys_gtype_instance_primitive_destroy_x, "%gtype-instance-primiti
 
 SCM_DEFINE (scm_gtype_instance_primitive_to_type, "gtype-instance-primitive->type", 1, 0, 0,
 	    (SCM instance),
-	    "")
+	    "Retrieve the @code{<gtype>} object associated with the primitive "
+            "@code{<%gtype-instance>} value, @var{instance}.")
 #define FUNC_NAME s_scm_gtype_instance_primitive_to_type
 {
     GTypeInstance *ginstance;
@@ -795,7 +803,14 @@ SCM_KEYWORD (k_gtype,		"gtype");
 SCM_DEFINE (scm_especify_metaclass_x,
             "especify-metaclass!", 2, 0, 0,
 	    (SCM class, SCM metaclass),
-	    "")
+	    "A terrible hack that takes a class @var{class} and sets its "
+            "metaclass, in-place, to @var{metaclass}. @var{metaclass} must "
+            "be a subclass of @var{class}' existing metaclass.\n\n"
+            "This method is useful if you want to define a method that "
+            "on a particular @code{<gtype-class>}, such as "
+            "@code{make-instance}. However, it would be cleaner to "
+            "devise a way of making these ``class methods'' without "
+            "molesting GOOPS in this way.")
 #define FUNC_NAME s_scm_especify_metaclass_x
 {
     SCM sgtype, new_class;
@@ -856,88 +871,6 @@ SCM_DEFINE (scm_sys_set_struct_slot, "%set-struct-slot!", 3, 0, 0,
 }
 #undef FUNC_NAME
 
-/* 1. methods of generic functions can come from any module.
- *    eg gst_props_entry_get and g_object_get.
- *
- * 2. the generic function can only be defined in one place, or it loses
- *    all knowledge of other methods (gst_props_entry_get replaces all
- *    definitions from other modules, eg g_object_get.)
- *
- * 3. therefore, we export the bindings for generics to the root module
- *
- * This is a temporary hack. We will be more sane we move to Guile 1.{7,8},
- * because the module system will have support for merging generic functions.
- */
-
-SCM_DEFINE (scm_sys_function_to_method_public,
-            "%function->method-public", 3, 0, 0,
-	    (SCM proc, SCM of_object, SCM generic_name),
-	    "")
-#define FUNC_NAME s_scm_sys_function_to_method_public
-{
-    static SCM the_root_module = SCM_BOOL_F, module_add_x = SCM_BOOL_F;
-    SCM arg_syms, specializers, generic, meth, closure;
-    int i;
-    char buffer[32];
-  
-    if (SCM_FALSEP (the_root_module)) {
-        the_root_module = scm_permanent_object
-            (SCM_VARIABLE_REF (scm_c_lookup ("the-root-module")));
-        module_add_x = scm_permanent_object
-            (SCM_VARIABLE_REF (scm_c_lookup ("module-add!")));
-    }
-
-    SCM_VALIDATE_PROC (0, proc);
-
-    /* use a previously available generic, if possible */
-    generic = scm_sym2var (generic_name,
-                           scm_module_lookup_closure (the_root_module),
-                           SCM_BOOL_F);
-    if (SCM_NFALSEP (generic)) {
-        generic = scm_variable_ref (generic);
-        
-        if (!SCM_IS_A_P (generic, scm_class_generic)) {
-            /* if the existing value is not a generic, we choose a new name */
-            gchar *new_name = g_strconcat (".", SCM_SYMBOL_CHARS (generic_name), NULL);
-            generic_name = scm_str2symbol (new_name);
-            g_free (new_name);
-            generic = SCM_BOOL_F;
-        }
-    }
-
-    /* make the method's specializer list */
-    arg_syms = specializers = SCM_EOL;
-    for (i = SCM_NUM2INT (0, SCM_CAR (scm_i_procedure_arity (proc))) - 1; i > 0; i--) {
-        specializers = scm_cons (scm_class_top, specializers);
-        sprintf (buffer, "arg%d", i);
-        arg_syms = scm_cons (scm_str2symbol (buffer), arg_syms);
-    }
-    specializers = scm_cons (of_object, specializers);
-    arg_syms = scm_cons (scm_str2symbol ("obj"), arg_syms);
-  
-    /* make a new generic if needed, and add it to the root module */
-    if (SCM_FALSEP (generic)) {
-        generic = scm_call_1 (_make, scm_class_generic);
-        scm_call_3 (module_add_x, the_root_module, generic_name,
-                    scm_make_variable (generic));
-        scm_set_procedure_property_x (generic, sym_name, generic_name);
-    }
-  
-    /* proc has to be a closure: methinks this is a goops bug */
-    closure = scm_closure (scm_list_2 (arg_syms, scm_cons (proc, arg_syms)),
-                           scm_top_level_env (SCM_TOP_LEVEL_LOOKUP_CLOSURE));
-    
-    /* make the method, and add it to the generic */
-    meth = scm_apply_0 (_make,
-                        scm_list_5 (scm_class_method,
-                                    scm_c_make_keyword ("specializers"), specializers,
-                                    scm_c_make_keyword ("procedure"), closure));
-    scm_add_method (generic, meth);
-
-    return SCM_UNSPECIFIED;
-}
-#undef FUNC_NAME
-
 
 
 /**********************************************************************
