@@ -35,7 +35,7 @@
 (define-class <gtk-wrapset> (<gobject-wrapset-base>)
   #:id 'gnome-gtk
   #:dependencies '(standard gnome-glib gnome-gobject
-                   gnome-atk gnome-pango gnome-gdk))
+                   gnome-atk gnome-cairo gnome-pango gnome-gdk))
 
 (define-method (global-declarations-cg (self <gtk-wrapset>))
   (list (next-method)
